@@ -3,7 +3,7 @@ package Test::BDD::Infrastructure::File;
 use strict;
 use warnings;
 
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 # ABSTRACT: cucumber step definitions for checking files
  
 use Test::More;
@@ -74,7 +74,7 @@ Then qr/the file type must be character device/, sub {
 Then qr/the file mode must be (\d+)/, sub {
 	my $mode = $1;
 	my $path = S->{'path'};
-	my $file_mode = sprintf("%04o", (stat($path))[2] & 07777 );
+	my $file_mode = sprintf("%04o", (stat($path))[2] & oct(7777) );
 	cmp_ok( $file_mode, 'eq', $mode, "file mode of $path must be $mode");
 };
 Then qr/the file must be owned by user (\S+)/, sub {
@@ -178,7 +178,7 @@ Test::BDD::Infrastructure::File - cucumber step definitions for checking files
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 Synopsis
 
